<?php

namespace B2buy\Master\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use B2buy\Master\Actions\MastersAction;
use B2buy\Master\Http\Requests\MastersActionRequest;
use B2buy\Master\Http\Resources\MastersResource;
use B2buy\Master\Models\Masters;

/**
 * Admin web controller class.
 */
class MastersActionController extends BaseController
{

    /**
     * Action controller function for masters.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(MastersActionRequest $request, Masters $masters, $action)
    {
        try {
            $request = $request->all();
            $masters = MastersAction::run($action, $masters, $request);

            $data = new MastersResource($masters);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('master::masters.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('master/masters/' . $masters->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('master/masters/' . $masters->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
