<?php

namespace B2buy\Master\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use B2buy\Master\Events\MastersAction as MastersActionEvent;
use B2buy\Master\Notifications\MastersAction as MastersActionNotification;
use Litepie\Actions\Concerns\AsAction;

class MastersAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the MastersActionEvent.
     *
     * @param   MastersActionEvent  $event
     * @return mixed
     */
    public function handle(MastersActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $masters.
     *
     * @param   MastersActionEvent  $event
     * @return void
     */
    public function create(MastersActionEvent $event)
    {
        $client = $event->masters->client;
        Notification::send($client, new MastersActionNotification($event));
    }

    /**
     * Handle the MastersActionEvent as a listener.
     *
     * @param   MastersActionEvent  $event
     * @return mixed
     */
    public function asListener(MastersActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   MastersActionEvent  $event
     * @return bool
     */
    private function isAllowed(MastersActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
