<?php

namespace B2buy\Master\Policies;

use Illuminate\Foundation\Auth\User as Authenticatable;
use B2buy\Master\Models\Masters;

class MastersPolicy
{

    use MastersAction;
    use MastersWorkflow;

    /**
     * Determine if the given user can view the masters.
     *
     * @param Authenticatable $user
     * @param Masters $masters
     *
     * @return bool
     */
    public function view(Authenticatable $user, Masters $masters)
    {
        if ($authUser->canDo('master.masters.view') && $authUser->isAdmin() || $user->isClient()) {
            return true;
        }

        return $masters->is_owner;
    }

    /**
     * Determine if the given user can create a masters.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function create(Authenticatable $user)
    {
        return  $authUser->canDo('master.masters.create');
    }

    /**
     * Determine if the given user can update the given masters.
     *
     * @param Authenticatable $user
     * @param Masters $masters
     *
     * @return bool
     */
    public function update(Authenticatable $user, Masters $masters)
    {
        if ($user->canDo('master.masters.edit') && $user->isAdmin()) {
            return true;
        }

        return $masters->is_owner;
    }

    /**
     * Determine if the given user can delete the given masters.
     *
     * @param Authenticatable $user
     *
     * @return bool
     */
    public function destroy(Authenticatable $user, Masters $masters)
    {
        return $masters->is_owner;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
